summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--jstests/replsets/slavedelay1.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/jstests/replsets/slavedelay1.js b/jstests/replsets/slavedelay1.js
index 040c47d3e78..fdab1feada6 100644
--- a/jstests/replsets/slavedelay1.js
+++ b/jstests/replsets/slavedelay1.js
@@ -42,11 +42,11 @@ doTest = function(signal) {
sleep(1000);
}
// within 30 seconds delayed slave should have it
assert.soon(function() {
var z = slaves[1].foo.findOne();
return z && z.x == 1;
- });
+ }, 'waiting for inserted document ' + tojson(doc) + ' on delayed slave', 120 * 1000);
/************* Part 2 *******************/
@@ -42,11 +42,11 @@ doTest = function(signal) {
sleep(1000);
}
- // within 30 seconds delayed slave should have it
+ // within 120 seconds delayed slave should have it
assert.soon(function() {
var z = slaves[1].foo.findOne();